==> claromentis-framework-9.6.6-26891208.zip: web/intranet/infocapture/classes/Event/FieldPermissionUpdateEvent.php <==
<?php
namespace Claromentis\Infocapture\Event;

$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] ?: array()) + array();
use Claromentis\Core\Event\Event;
use Claromentis\Infocapture\Model\ICFieldGroup;
use HDFieldsRule;
use HDProject;
class FieldPermissionUpdateEvent extends Event implements ProjectEventInterface
{
    
    
    
    
    protected $project;
    
    
    
    
    protected $rule;
    
    
    
    
    protected $group;
    
    
    
    
    protected $bitmask;
    
    
    
    
    protected $right;
    
    
    
    
    protected $value;
    
    
    
    
    
    
    
    
    
    public function __construct(HDProject $project, HDFieldsRule $_4b020cf7a9abbc88937c40b6bc7a97e9, ICFieldGroup $_e9208e4fb555ac989f7519e19c1da810, int $_113231a8421952bea7afa7b2a1b45a8c, string $_18f48e103c59a05cbe75b66b44ec5728, int $value)
    {
        $this->project = $project;
        $this->rule = $_4b020cf7a9abbc88937c40b6bc7a97e9;
        $this->group = $_e9208e4fb555ac989f7519e19c1da810;
        $this->bitmask = $_113231a8421952bea7afa7b2a1b45a8c;
        $this->right = $_18f48e103c59a05cbe75b66b44ec5728;
        $this->value = $value;
    }
    
    
    
    
    public function getProject() : HDProject
    {
        return $this->project;
    }
    
    
    
    
    public function getRule() : HDFieldsRule
    {
        return $this->rule;
    }
    
    
    
    
    public function getGroup() : ICFieldGroup
    {
        return $this->group;
    }
    
    
    
    
    public function getBitmask() : int
    {
        return $this->bitmask;
    }
    
    
    
    
    public function getRight() : string
    {
        return $this->right;
    }
    
    
    
    
    public function getValue() : int
    {
        return $this->value;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/infocapture/classes/Event/FieldPermissionUpdateEvent.php <==
<?php
namespace Claromentis\Infocapture\Event;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] ?: array()) + array();
use Claromentis\Core\Event\Event;
use Claromentis\Infocapture\Model\ICFieldGroup;
use HDFieldsRule;
use HDProject;
class FieldPermissionUpdateEvent extends Event implements ProjectEventInterface
{
    
    
    
    
    protected $project;
    
    
    
    
    protected $rule;
    
    
    
    
    protected $group;
    
    
    
    
    protected $bitmask;
    
    
    
    
    protected $right;
    
    
    
    
    protected $value;
    
    
    
    
    
    
    
    
    
    public function __construct(HDProject $project, HDFieldsRule $_4b020cf7a9abbc88937c40b6bc7a97e9, ICFieldGroup $_e9208e4fb555ac989f7519e19c1da810, int $_113231a8421952bea7afa7b2a1b45a8c, string $_18f48e103c59a05cbe75b66b44ec5728, int $value)
    {
        $this->project = $project;
        $this->rule = $_4b020cf7a9abbc88937c40b6bc7a97e9;
        $this->group = $_e9208e4fb555ac989f7519e19c1da810;
        $this->bitmask = $_113231a8421952bea7afa7b2a1b45a8c;
        $this->right = $_18f48e103c59a05cbe75b66b44ec5728;
        $this->value = $value;
    }
    
    
    
    
    public function getProject() : HDProject
    {
        return $this->project;
    }
    
    
    
    
    public function getRule() : HDFieldsRule
    {
        return $this->rule;
    }
    
    
    
    
    public function getGroup() : ICFieldGroup
    {
        return $this->group;
    }
    
    
    
    
    public function getBitmask() : int
    {
        return $this->bitmask;
    }
    
    
    
    
    public function getRight() : string
    {
        return $this->right;
    }
    
    
    
    
    public function getValue() : int
    {
        return $this->value;
    }
}
